clear;
clf;
global D m N n L eps sigma kb gamma T rgb W

kb = 1   % Boltzmann's constant
D = 2    % spacial dimension
m = 1    % particle mass
n = 10    % number of lattice sites
N = n*n  % total number of particles 

eps = 1;            % parameter 1 in Lennard Jones pot
sigma = 2^(-1/6);  % parameter 2 in Lennard Jones pot
gamma = 0.00001;      % parameter in Langevin equation
T0 = 35;          % initial temperature

a = 0.978*sigma;   % lattice spacing
L = n*2;           % length of simulation cell in X
W = n*1;            % width of simulation cell in Y

rgb = zeros(N,1);       %set redox status tracking vector

y0 = zeros(2*D*N,1);             % create y vector
y0 = initial_positions(y0);      % set inital positions
y0 = initial_velocities(y0,T0);  % set initial velocities


tEq = 0.5;       % equilibration time
tMax = 10;        % total simulation time
t=0;                % starting time
dt = 0.002;          % time step

plot_positions(y0); % plot positions

y=y0;               % initialize y vector but keep a record of initial state as y0

C = 0;          %set counter variable

T = kinetic_energy(y) / (3/2*N*kb)      %compute initial temperature for Langevin equation's noise term


while (t<tEq)      % equilibration loop; rgb is not used in this part; electrode OFF
    
    % do one Runge-Kutta step
    f1 = ode(t     ,y);
    f2 = ode(t+dt/2,y+(dt/2).*f1);
    f3 = ode(t+dt/2,y+(dt/2).*f2);
    f4 = ode(t+dt  ,y+ dt   .*f3);
    y = y+dt/6.*(f1+2*f2+2*f3+f4);
    
    %Reflective walls; check position of all particles; if at a wall and
    %velocity vector pointing towards wall, reflect the velocity vector
    %(angle i = angle r)
    for k = 1:N
        if y(2*k-1) < 0.05 
            if sign(y(D*N + 2*k - 1)) == -1
                y(D*N + 2*k - 1) = -y(D*N + 2*k - 1);
            end
        elseif y(2*k-1) > L-0.05
            if sign(y(D*N + 2*k - 1)) == 1
                y(D*N + 2*k - 1) = -y(D*N + 2*k -1);
            end
        elseif y(2*k) < 0.05
            if sign(y(D*N + 2*k)) == -1
                y(D*N + 2*k) = -y(D*N + 2*k);
            end
        elseif y(2*k) > W-0.05
            if sign(y(D*N + 2*k)) == 1
                y(D*N + 2*k) = -y(D*N + 2*k);
            end
        end
    end
            
    %move time up a step
    t = t + dt;
    
    % compute and print kinetic, potential, and total energy
    % from kinetic energy determine current temperature T
    K = kinetic_energy(y);
    T = K / (3/2*N*kb);
    V = potential_energy(y);
    E = K+V;
    fprintf('t= %.3f E= %f K= %.3f V= %.3f T= %f\n',t,E,K,V,T);
    
    % plot current positions (subplotted)
    plot_positionsEq(y);
    drawnow
    
    % plot density distribution (subplotted)
    compute_density_distsmooth(y);
    drawnow
    
    %set so that image is saved every 5 iterations 
    iteration = floor(t/dt);
    
    if mod(iteration,5) == 0
       C = C+1;
    end
    
    if mod(iteration,5) == 0
       saveas(gcf,['ElecDiff',sprintf('%03d',C),'.png'])
    end

    
end

while (t<tMax)      % main loop, ELECTRODE ON!!
    
    % do one Runge-Kutta step
    f1 = ode(t     ,y);
    f2 = ode(t+dt/2,y+(dt/2).*f1);
    f3 = ode(t+dt/2,y+(dt/2).*f2);
    f4 = ode(t+dt  ,y+ dt   .*f3);
    y = y+dt/6.*(f1+2*f2+2*f3+f4);
    
    %Reflective walls; check position of all particles; if at a wall and
    %velocity vector pointing towards wall, reflect the velocity vector
    %(angle i = angle r)
    for k = 1:N
        if y(2*k-1) < 0.05
            if sign(y(D*N + 2*k - 1)) == -1
                y(D*N + 2*k - 1) = -y(D*N + 2*k - 1);
            end
        elseif y(2*k-1) > L-0.05
            if sign(y(D*N + 2*k - 1)) == 1
                y(D*N + 2*k - 1) = -y(D*N + 2*k -1);
            end
        elseif y(2*k) < 0.05
            if sign(y(D*N + 2*k)) == -1
                y(D*N + 2*k) = -y(D*N + 2*k);
            end
        elseif y(2*k) > W-0.05
            if sign(y(D*N + 2*k)) == 1
                y(D*N + 2*k) = -y(D*N + 2*k);
            end
        end
    end
            
    %move time up a step
    t = t + dt;
    
    % compute and print kinetic, potential, and total energy
    % from kinetic energy determine current temperature T
    K = kinetic_energy(y);
    T = K / (3/2*N*kb);
    V = potential_energy(y);
    E = K+V;
    fprintf('t= %.3f E= %f K= %.3f V= %.3f T= %f\n',t,E,K,V,T);

    % plot current positions, using rgb vector to determine reduced
    % particles and oxidants (subplotted)
    plot_positions(y);
    drawnow
    
    % plot density distribution (subplotted)
    compute_density_distsmooth(y);
    drawnow
    
    %set so that image is saved every 5 iterations
    iteration = floor(t/dt);
    
    if mod(iteration,5) == 0
       C = C+1;
    end
    
    if mod(iteration,5) == 0
       saveas(gcf,['ElecDiff',sprintf('%03d',C),'.png'])
    end

end

