
function ydot = ode(t,y)
 
global N D m gamma kb T
 
% y is long column vector
% containing 2*(D=2)*N elements
% first r(1) r(2) ... r(N)
% then  v(1) v(2) ... v(N)
 
% loop over all particles
% and determite rdot from the velocties
 
ydot = zeros(2*D*N,1);
ydot(1:D*N) = y(D*N+1:2*D*N);

for i = 1:N-1
    for j = i+1:N
        ri = [y(D*i-1); y(D*i)];
        rj = [y(D*j-1); y(D*j)];
        d = distancePBC(ri,rj);
        
        %generate Langevin friction correction in terms of acceleration
        vi = [ydot(2*i-1); ydot(2*i)];
        vj = [ydot(2*j-1); ydot(2*j)];
        frici = -gamma.*vi;
        fricj = -gamma.*vj;
        
        %generate Langevin noise correction in terms of acceleration
        noisei = [randn(); randn()];
        noisej = [randn(); randn()];
        noisei = (sqrt(2*gamma*kb*T*m)/m).*noisei;
        noisej = (sqrt(2*gamma*kb*T*m)/m).*noisej;
        
        %compute total acceleration vector
        aij = -potentialderivative(norm(d))*(1/m).*(d./norm(d)) + frici + noisei;
        aji = potentialderivative(norm(d))*(1/m).*(d./norm(d)) + fricj + noisej;
        aijx = aij(1,1);
        ajix = aji(1,1);
        aijy = aij(2,1);
        ajiy = aji(2,1);
        if i==j
            aijx =0;
            aijy =0;
            ajix = 0;
            ajiy = 0;
        end
        ydot(D*(N+i)-1) = ydot(D*(N+i)-1) + aijx;
        ydot(D*(N+i)) = ydot(D*(N+i)) + aijy;
        ydot(D*(N+j)-1) = ydot(D*(N+j)-1) + ajix;
        ydot(D*(N+j)) = ydot(D*(N+j)) + ajiy;     
    end
end
