function plot_positions(y)

% plot positions of particles, taking into account an active electrode.
% Employed a identification vector rgb to identify if a particle had been
% reduced.  Oxidants are reduced when they come within 1 unit of the left
% wall.  The reduction is recorded by changing the particle's identifying
% number in rgb from 0 to 1.  So 0 = oxidant, 1 = reduced

global N L rgb W

clf;



for i = 1:N
    rx(i,1) = y(2*i-1);
    ry(i,1) = y(2*i);
    rx(i,1) = map_inside(rx(i,1));
    ry(i,1) = map_inside(ry(i,1));
    
    %determine if any particles are within proximity of electrode, and set
    %their identifier in rgb to 1.
    if rx(i,1) < 1
        rgb(i,1) = 1;
    end   
end


subplot(2,1,1);
axis([0 L 0 W]);

%plot the positions of all the particles.  Use rgb to determine if a
%particle should be blue (oxidant) or red (reduced)
for j = 1:N
    if rgb(j) == 0
        plot(rx(j),ry(j),'bo','MarkerFaceColor','b','MarkerSize',5);
    else plot(rx(j),ry(j),'ro','MarkerFaceColor','r','MarkerSize',5);
    end
    hold on;
end

ylabel('Electrode')



